dialogId("cil-v-hlaska0", "font_big", "I think we have a job to do here.")
dialogStr("Мисля, че имаме да вършим работа тук.")

dialogId("cil-m-hlaska0", "font_small", "I think we have a job to do here.")
dialogStr("Мисля, че имаме работа за вършене тук.")

dialogId("cil-v-hlaska1", "font_big", "We didn’t fulfill our mission yet.")
dialogStr("Още не сме изпълнили мисията си.")

dialogId("cil-m-hlaska1", "font_small", "We didn’t fulfill our mission yet.")
dialogStr("Още не сме изпълнили мисията си.")

dialogId("cil-m-hlaska2", "font_small", "The Agency relies upon us. We must not fail.")
dialogStr("Агенцията разчита на нас. Не трябва да се проваляме.")

dialogId("cil-v-hlaska2", "font_big", "The Agency relies upon us. We must not fail.")
dialogStr("Агенцията разчита на нас. Не трябва да се проваляме.")

dialogId("cil-v-hlaska3", "font_big", "Certainly, we are not going to run away with the end in sight.")
dialogStr("Естествено няма да се откажем, когато краят се вижда.")

dialogId("cil-m-hlaska3", "font_small", "Certainly, we are not going to run away with the end in sight.")
dialogStr("Естествено няма да се откажем, когато краят се вижда.")

